@@ -1,7 +1,8 @@
 /*
  * gpe-shield
  *
- * Copyright (C) 2004, 2006 Florian Boor <florian.boor@kernelconcepts.de>
+ * Copyright (C) 2004 kernel concepts
+ * Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,26 +76,26 @@ update_widgets(GtkWidget* sender)
 
 
 static GtkWidget*
-create_dialog(void)
+create_dialog()
 {
-	GtkWidget *dialog, *label, *table, *sw;
+	GtkWidget *dialog, *label, *table;
 	gchar *text;
 	GList *slTarget = NULL;
 	GList *slChain = NULL;
 	GList *slProtocol = NULL;
 	
-	slTarget = g_list_append(slTarget, VAL_ACCEPT);
-	slTarget = g_list_append(slTarget, VAL_DROP);
-	slTarget = g_list_append(slTarget, VAL_REJECT);
+	slTarget = g_list_append(slTarget,VAL_ACCEPT);
+	slTarget = g_list_append(slTarget,VAL_DROP);
+	slTarget = g_list_append(slTarget,VAL_REJECT);
 
-	slChain = g_list_append(slChain, VAL_INPUT);
-	slChain = g_list_append(slChain, VAL_OUTPUT);
-	slChain = g_list_append(slChain, VAL_FORWARD);
+	slChain = g_list_append(slChain,VAL_INPUT);
+	slChain = g_list_append(slChain,VAL_OUTPUT);
+	slChain = g_list_append(slChain,VAL_FORWARD);
 	
-	slProtocol = g_list_append(slProtocol, VAL_TCP);
-	slProtocol = g_list_append(slProtocol, VAL_UDP);
-	slProtocol = g_list_append(slProtocol, VAL_ICMP);
-	slProtocol = g_list_append(slProtocol, VAL_ALL);
+	slProtocol = g_list_append(slProtocol,VAL_TCP);
+	slProtocol = g_list_append(slProtocol,VAL_UDP);
+	slProtocol = g_list_append(slProtocol,VAL_ICMP);
+	slProtocol = g_list_append(slProtocol,VAL_ALL);
 	
 	dialog = 
 		gtk_dialog_new_with_buttons(_("Edit rule"),
@@ -104,25 +105,17 @@ create_dialog(void)
 	                                GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 	                                GTK_STOCK_OK,GTK_RESPONSE_OK,
 	                                NULL);
-	gtk_window_set_default_size(GTK_WINDOW(dialog), 240, 300);
-	sw = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw), 
-	                               GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	table = gtk_table_new(4,3,FALSE);
+	gtk_table_set_col_spacings(GTK_TABLE(table),gpe_get_boxspacing());
+	gtk_table_set_row_spacings(GTK_TABLE(table),gpe_get_boxspacing());
+	gtk_container_set_border_width(GTK_CONTAINER(table),gpe_get_border());
 	
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), sw, TRUE, TRUE, 0);
-	
-	table = gtk_table_new(4, 3, FALSE);
-	gtk_table_set_col_spacings(GTK_TABLE(table), gpe_get_boxspacing());
-	gtk_table_set_row_spacings(GTK_TABLE(table), gpe_get_boxspacing());
-	gtk_container_set_border_width(GTK_CONTAINER(table), gpe_get_border());
-	
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(sw), table);
-	gtk_viewport_set_shadow_type(GTK_VIEWPORT(table->parent), GTK_SHADOW_NONE);
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),table,TRUE,TRUE,0);
 	
 	label = gtk_label_new(NULL);
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	text = g_strdup_printf("<b>%s</b>", _("Edit rule parameters"));
-	gtk_label_set_markup(GTK_LABEL(label), text);
+	gtk_misc_set_alignment(GTK_MISC(label),0,0.5);
+	text = g_strdup_printf("<b>%s</b>",_("Edit rule parameters"));
+	gtk_label_set_markup(GTK_LABEL(label),text);
 	g_free(text);
 	gtk_table_attach(GTK_TABLE(table),label,0,2,0,1,GTK_FILL | GTK_EXPAND,GTK_FILL,0,0);
 	
@@ -185,8 +178,6 @@ edit_rule(rule_t *rule)
 {
 	int i;
 	char *text;
-		
-	edit_dialog = create_dialog();
 	
 	/* check if we need to allocate a new rule */
 	if (rule == NULL)
@@ -194,10 +185,11 @@ edit_rule(rule_t *rule)
 		rule = malloc(sizeof(rule_t));
 		memset(rule,0,sizeof(rule_t));
 		/* set some defaults */
-		sprintf(rule->name,"%s", _("New rule"));
-		gtk_window_set_title(GTK_WINDOW(edit_dialog), _("Add Rule"));
+		sprintf(rule->name,"%s",_("New rule"));
 	}
 	
+	edit_dialog = create_dialog();
+	
 	/* fill in values */
 	gtk_entry_set_text(GTK_ENTRY(eName),rule->name);
 	for (i=0;i<n_chain;i++)
