@@ -1,2 +1,2 @@
 char *s = N_("Change security settings and access control");
-char *s = N_("Network Shield");
+char *s = N_("Desktop Firewall");
