@@ -1,7 +1,7 @@
 /*
  * gpe-shield
  *
- * Copyright (C) 2004, 2006  kernel concepts
+ * Copyright (C) 2004  kernel concepts
  * Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
@@ -18,6 +18,26 @@
 #include <unistd.h>
 #include <dirent.h>
 #include <fcntl.h>
+#include <stropts.h>
+#include <poll.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <sys/signal.h>
+#include <sys/un.h>
+
+#include <locale.h>
+#include <libintl.h>
+#define _(x) gettext(x)
+
+#include <gtk/gtk.h>
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <dirent.h>
+#include <fcntl.h>
+#include <stropts.h>
 #include <poll.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -70,7 +90,7 @@ static int rules_altered = 0;
 static GtkWidget *notebook;
 static GtkWidget *treeview;
 static GtkTreeStore *store = NULL;
-static GtkToolItem *bApply, *bAdd, *bRemove, *bEdit;
+static GtkWidget *bApply, *bAdd, *bRemove, *bEdit;
 static GtkWidget *miLoad, *miSave, *miApply;
 static GtkWidget *mMain;
 GtkWidget *fMain;
@@ -94,16 +114,17 @@ void update_tree(void);
 
 static GtkItemFactoryEntry mMain_items[] = {
   { N_("/_File"),         NULL,         NULL, MI_FILE, "<Branch>" },
-  { N_("/File/_Load"), "", on_load_clicked, MI_OPEN, "<StockItem>", GTK_STOCK_OPEN},
+  { N_("/File/_Open"), "", on_load_clicked, MI_OPEN, "<StockItem>", GTK_STOCK_OPEN},
   { N_("/File/_Save"), "", on_save_clicked, MI_SAVE, "<StockItem>", GTK_STOCK_SAVE},
   { N_("/_File/s1"), NULL , NULL,    0, "<Separator>"},
   { N_("/File/_Close"),  NULL, do_safe_exit, 0, "<StockItem>", GTK_STOCK_QUIT },
   { N_("/_Rules"),         NULL,         NULL, 0, "<Branch>" },
   { N_("/Rules/_Add"), "", on_add_clicked, MI_ADD , "<StockItem>", GTK_STOCK_ADD},
-  { N_("/Rules/_Edit"), "", on_edit_clicked, MI_ADD , "<StockItem>", GTK_STOCK_PROPERTIES},
+  { N_("/Rules/_Edit"), "", on_add_clicked, MI_ADD , "<StockItem>", GTK_STOCK_PROPERTIES},
   { N_("/Rules/_Delete"), "", on_remove_clicked, MI_DELETE , "<StockItem>", GTK_STOCK_DELETE},
+  { N_("/Rules/_Info"), "", on_info_clicked, MI_INFO , "<Item>"},
   { N_("/Rules/s2"), NULL , NULL,    0, "<Separator>"},
-  { N_("/Rules/Appl_y"), "", on_rules_apply_clicked, MI_RULES_APPLY, "<StockItem>", GTK_STOCK_APPLY},
+  { N_("/Rules/_Apply"), "", on_rules_apply_clicked, MI_RULES_APPLY, "<StockItem>", GTK_STOCK_APPLY},
   { N_("/_Help"),         NULL, NULL,           0, "<Branch>" },
   { N_("/_Help/Index"),   NULL, on_help_clicked,    0, "<StockItem>",GTK_STOCK_HELP },
   { N_("/_Help/About"),   NULL, on_about_clicked,    0, "<Item>" },
@@ -182,15 +203,6 @@ wait_command_finish()
 
 /* --- local intelligence --- */
 
-static gboolean
-rules_can_load(void)
-{
-	if (access(CONFIGFILE, F_OK))
-		return FALSE;
-	else
-		return TRUE;
-}
-
 
 static void
 do_shutdown(void)
@@ -374,7 +386,7 @@ on_add_clicked (GtkWidget * w)
 {
 	rule_t *newrule;
 	
-	newrule = edit_rule(NULL); /* returns new rule or NULL on abort */
+	newrule = edit_rule(NULL); /* returns up to date rule or NULL on abort */
 	
 	if (newrule != NULL) 
 	{
@@ -447,7 +459,6 @@ void
 on_rules_apply_clicked (GtkWidget * w)
 {
 	send_message(PK_COMMAND,CMD_SET,NULL);
-	show_message(GTK_MESSAGE_INFO, _("Rules applied."));
 }
 
 
@@ -457,6 +468,8 @@ update_tree(void)
 	int i;
 	GtkTreeIter iter;
 
+
+#warning improve this
 	gtk_tree_store_clear(GTK_TREE_STORE(store));
 	
 	for (i=0;i<rule_count;i++)
@@ -490,12 +503,10 @@ on_help_clicked (GtkWidget * w)
 void
 change_network_control (GtkWidget * w)
 {
-	gboolean state;
-	
-	state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w));
-	
-	send_message(PK_COMMAND,state ? CMD_CFG_LOAD : CMD_CFG_DONTLOAD, NULL);
-	gtk_widget_set_sensitive(GTK_WIDGET(bApply),state);
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)))
+		send_message(PK_COMMAND,CMD_CFG_LOAD,NULL);
+	else
+		send_message(PK_COMMAND,CMD_CFG_DONTLOAD,NULL);
 }
 
 
@@ -529,10 +540,10 @@ void do_message_dlg(int type,char *msg)
 
 void do_end_command()
 {
-    gtk_widget_set_sensitive(miLoad, rules_can_load());
-    gtk_widget_set_sensitive(miSave, TRUE);
-    gtk_widget_set_sensitive(miApply, get_network_control());
-    gtk_widget_set_sensitive(GTK_WIDGET(bApply), get_network_control());
+    gtk_widget_set_sensitive(miLoad,TRUE);
+    gtk_widget_set_sensitive(miSave,TRUE);
+    gtk_widget_set_sensitive(miApply,TRUE);
+    gtk_widget_set_sensitive(bApply,TRUE);
 	if (running_command == CMD_ADD) 
 		update_tree();
 	running_command = CMD_NONE;
@@ -564,19 +575,6 @@ void do_safe_exit()
 	gtk_main_quit();
 }
 
-static void
-do_status(pkcommand_t cmd)
-{
-	if (cmd == CMD_NO_IPTABLES)
-		show_message(GTK_MESSAGE_WARNING, _("This system does not " \
-	                                        "support firewalling or you"\
-	                                        " don't have the right to "\
-	                                        "change firewall rules, this" \
-	                                        " application will exit now."));
-	do_shutdown();
-	gtk_main_quit();
-	exit(0);
-}
 
 gboolean
 get_pending_messages ()
@@ -590,8 +588,7 @@ get_pending_messages ()
 		if ((pfd[0].revents & POLLERR) || (pfd[0].revents & POLLHUP))
 		{
 			perror ("ERR: connection lost: ");
-			do_message_dlg(GTK_MESSAGE_ERROR,
-			               _("Backend failure, cannot continue."));
+			do_message_dlg(GTK_MESSAGE_ERROR,_("Backend failure, cannot continue."));
 			close(sock);
 			exit(1);
 		}
@@ -599,8 +596,7 @@ get_pending_messages ()
 		{
 			perror ("ERR: receiving data packet");
 			close (sock);
-			do_message_dlg(GTK_MESSAGE_ERROR,
-			               _("Communication error, cannot continue."));
+			do_message_dlg(GTK_MESSAGE_ERROR,_("Communication error, cannot continue."));
 			exit (1);
 		}
 		else
@@ -615,14 +611,9 @@ get_pending_messages ()
 				do_end_command();
 				break;
 				case PK_RULE:
-#ifdef DEBUG				
 					printf("got rule\n");
-#endif				
 					do_rule_add(&msg.content.tf.rule);
 				break;
-				case PK_STATUS:
-					do_status(msg.content.tf.command);
-				break;
 			default:
 				break;
 			}
@@ -683,6 +674,9 @@ mainloop (int argc, char *argv[])
 	if (rule_count == 0) 
 		add_default_policies();
 	update_tree();
+	/* activate current rules */
+	send_message(PK_COMMAND,CMD_SET,NULL);
+	wait_command_finish();
 	
 	gtk_main ();
 
@@ -691,6 +685,25 @@ mainloop (int argc, char *argv[])
 	return 0;
 }
 
+/*
+gboolean   
+tv_row_clicked(GtkTreeView *treeview, GtkTreePath *arg1, 
+	GtkTreeViewColumn *arg2, gpointer user_data)
+{
+	GtkTreeSelection *selection;
+	GtkTreeIter iter;
+	int status;
+
+	selection = gtk_tree_view_get_selection (treeview);
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter) == FALSE) 
+		return FALSE;
+	gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, COL_ACTIVE, &status, -1);
+	status = !status;
+	gtk_tree_store_set (GTK_TREE_STORE (store), &iter, COL_ACTIVE, status, -1);
+	return TRUE;
+}
+*/
+
 static void
 list_toggle_inst (GtkCellRendererToggle * cellrenderertoggle,
 		  gchar * path_str, gpointer model_data)
@@ -755,20 +768,20 @@ create_fMain (void)
   GtkWidget *vbox;
   GtkWidget *cur;
   GtkWidget *toolbar;
+  GtkWidget *pw;
   GtkTooltips *tooltips;
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
-  GtkToolItem *sep, *pw;
-  gchar *tmp;
-  gint size_x, size_y;
+  char *tmp;
+  	int size_x, size_y;
 
-  /* init tree storage stuff */
-  store = gtk_tree_store_new (N_COLUMNS,
-  			    G_TYPE_BOOLEAN,
-			    G_TYPE_STRING,
-				G_TYPE_STRING,
-			    G_TYPE_POINTER
-  );
+	/* init tree storage stuff */
+	store = gtk_tree_store_new (N_COLUMNS,
+				    G_TYPE_BOOLEAN,
+				    G_TYPE_STRING,
+					G_TYPE_STRING,
+				    G_TYPE_POINTER
+	);
 
   /* main window */
   size_x = gdk_screen_width() / 2;
@@ -795,57 +808,40 @@ create_fMain (void)
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
 			       GTK_ORIENTATION_HORIZONTAL);
 
-  bApply = gtk_tool_button_new_from_stock(GTK_STOCK_APPLY);
-  g_signal_connect(G_OBJECT(bApply), "clicked", 
-                   G_CALLBACK(on_rules_apply_clicked), NULL);
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), bApply, -1);
-  gtk_tooltips_set_tip(tooltips, GTK_WIDGET(bApply), 
-                       _("Apply rules to your system"), NULL);
-
-  bAdd = gtk_tool_button_new_from_stock(GTK_STOCK_ADD);
-  g_signal_connect(G_OBJECT(bAdd), "clicked", 
-                   G_CALLBACK(on_add_clicked), NULL);
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), bAdd, -1);
-  gtk_tooltips_set_tip(tooltips, GTK_WIDGET(bAdd), 
-                       _("Add a new rule"), NULL);
-			   			   
-  bRemove = gtk_tool_button_new_from_stock(GTK_STOCK_REMOVE);
-  g_signal_connect(G_OBJECT(bRemove), "clicked", 
-                   G_CALLBACK(on_remove_clicked), NULL);
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), bRemove, -1);
-  gtk_tooltips_set_tip(tooltips, GTK_WIDGET(bRemove), 
-                       _("Remove selected rule"), NULL);
-  		   
-  bEdit = gtk_tool_button_new_from_stock(GTK_STOCK_EDIT);
-  g_signal_connect(G_OBJECT(bEdit), "clicked", 
-                   G_CALLBACK(on_edit_clicked), NULL);
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), bEdit, -1);
-  gtk_tooltips_set_tip(tooltips, GTK_WIDGET(bRemove), 
-                       _("Edit selected rule"), NULL);
-
-  sep = gtk_separator_tool_item_new();
-  gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(sep), FALSE);
-  gtk_tool_item_set_expand(sep, TRUE);
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), sep, -1);
+  bApply = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_APPLY,
+			   _("Apply rules"), _("Apply rules"),
+			   (GtkSignalFunc) on_rules_apply_clicked , NULL, -1);
+			   
+  bAdd = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_ADD,
+			   _("Add rule"), _("Add rule"),
+			   (GtkSignalFunc) on_add_clicked , NULL, -1);
+			   
+  bRemove = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_REMOVE,
+			   _("Remove rule"), _("Remove Rule"),
+			   (GtkSignalFunc) on_remove_clicked , NULL, -1);
+			   
+  bEdit = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_PROPERTIES,
+			   _("Edit rule"), _("Edit Rule"),
+			   (GtkSignalFunc) on_edit_clicked , NULL, -1);
+			   
+  gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
   
-  pw = gtk_tool_button_new_from_stock(GTK_STOCK_QUIT);
-  g_signal_connect(G_OBJECT(pw), "clicked", 
-                   G_CALLBACK(do_safe_exit), NULL);
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), pw, -1);
-  gtk_tooltips_set_tip(tooltips, GTK_WIDGET(pw), 
-                       _("Close application"), NULL);
-					   			   
-  gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, TRUE, 0);
+  pw = gtk_image_new_from_pixbuf(gpe_find_icon ("exit"));
+  gtk_toolbar_append_item (GTK_TOOLBAR (toolbar), _("Exit"),
+			   _("Close application"), _("Close application"), pw,
+			   (GtkSignalFunc) do_safe_exit, NULL);
+			   
+  gtk_box_pack_start(GTK_BOX(vbox),toolbar,FALSE,TRUE,0);
 
   /* notebook */
   
   notebook = gtk_notebook_new();	
-  gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox),notebook,TRUE,TRUE,0);
 	
-  gtk_object_set_data(GTK_OBJECT(notebook), "tooltips", tooltips);
+  gtk_object_set_data(GTK_OBJECT(notebook),"tooltips",tooltips);
   
   /* installed tab */	
-  vbox = gtk_vbox_new(FALSE, gpe_get_boxspacing());
+  vbox = gtk_vbox_new(FALSE,gpe_get_boxspacing());
 
   cur = gtk_label_new(_("Rules"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook),vbox,cur);
@@ -869,6 +865,9 @@ create_fMain (void)
   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(treeview),TRUE);
   gtk_container_add(GTK_CONTAINER(cur),treeview);	
   
+/*	g_signal_connect_after (G_OBJECT (treeview), "cursor-changed",
+			  G_CALLBACK (tv_row_clicked), NULL);
+*/
 	renderer = gtk_cell_renderer_toggle_new ();
 	gtk_cell_renderer_toggle_set_radio(GTK_CELL_RENDERER_TOGGLE(renderer),FALSE);
 	g_signal_connect (G_OBJECT (renderer), "toggled",
@@ -906,14 +905,13 @@ create_fMain (void)
   free(tmp);
   gtk_box_pack_start(GTK_BOX(vbox),cur,FALSE,TRUE,0);	
   
-  cur = gtk_check_button_new_with_label(_("Network contol active"));
+  cur = gtk_check_button_new_with_label(_("Start network control on login"));
   gtk_box_pack_start(GTK_BOX(vbox),cur,FALSE,TRUE,0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cur),get_network_control());
   g_signal_connect_after (G_OBJECT (cur), "toggled",
 			  G_CALLBACK (change_network_control), NULL);
   
   g_signal_connect(G_OBJECT (fMain),"destroy",gtk_main_quit,NULL);
-  gtk_widget_set_sensitive(miLoad, rules_can_load());
   
   gtk_widget_show_all(fMain);
 }
